@@ -1,4 +1,4 @@
-// 	$Id: dicomInfo.cc,v 1.33 2007/10/15 17:15:46 valerio Exp $
+// 	$Id: dicomInfo.cc,v 1.36 2008/01/22 19:08:11 valerio Exp $
 
 //============================================================================
 // DCM is part of the CTN library, curtesy of
@@ -24,6 +24,7 @@
 #include "dicomInfo.h"
 #include <cstdlib>
 #include <iostream>
+#include <cstring>
 
 using namespace std;
 
@@ -83,8 +84,6 @@ DICOMImage::DICOMImage(const char *path) : error_(false),
 										   shadowSet_(NULL),
 										   numSlices_(0)
 {
-	bool retValues = true;
-
 	if ( ! OpenFile(path) )
 	{
 		error_ = true;
@@ -807,18 +806,18 @@ bool DICOMImage::GetACQEchoNumber()
   
    if (GetData(DCM_ACQECHONUMBER, &strn) == 0)
    {
-	  string msg("DICOMImage::GetACQEchoNumber: Cannot get value of echo number in image ");
-	  msg += imgPath_;
-	  cerr << endl << "\t**** " << msg << endl << endl;
-	  error_ = true;
-	  if (strn != NULL) delete [] strn;
-	  return false;
+	  error_ = false;
+	  COND_PopCondition(TRUE);				// Clear error from stack
+	  acqEchoNum_ = 0;
    }
+   else
+   {
+	   // Convert string to numerical value
 
-   // Convert string to numerical value
-
-   acqEchoNum_ = atoi(strn);
-   delete [] strn;
+	   acqEchoNum_ = atoi(strn);
+   }
+   
+   if (strn != NULL) delete [] strn;
    return true;
 }
 
@@ -928,19 +927,19 @@ bool DICOMImage::GetD3()
   
    if (GetData(DCM_ACQMRACQUISITIONTYPE, &strn) == 0)
    {
-	  string msg("DICOMImage::GetD3: Cannot get value of acquisition type in image ");
-	  msg += imgPath_;
-	  cerr << endl << "\t**** " << msg << endl << endl;
-	  error_ = true;
-	  if (strn != NULL) delete [] strn;
-	  return false;
+	  error_ = false;
+	  COND_PopCondition(TRUE);				// Clear error from stack
+	  d3_ = false;
    }
+   else
+   {
+	   // See if the string "3D" is there
 
-	// See if the string "3D" is there
-
-	d3_ = (strstr(strn, "3D") != NULL);
-	delete [] strn;
-	return true;
+	   d3_ = (strstr(strn, "3D") != NULL);
+   }
+   
+   if (strn != NULL) delete [] strn;
+   return true;
 }
 
 //////////////////////////////////////////////////////////////////////////////
@@ -964,17 +963,18 @@ bool DICOMImage::GetSliceThickness()
    if (GetData(DCM_ACQSLICETHICKNESS, &strn) == 0)
    {
 	  string msg("DICOMImage::SliceThickness: Cannot get value of slice thickness in image ");
-	  msg += imgPath_;
-	  cerr << endl << "\t**** " << msg << endl << endl;
-	  error_ = true;
-	  if (strn != NULL) delete [] strn;
-	  return false;
+	  error_ = false;
+	  COND_PopCondition(TRUE);				// Clear error from stack
+	  sliceThickness_ = 1.;
    }
+   else
+   {
+	   // Convert string to numerical value
 
-   // Convert string to numerical value
-
-   sscanf(strn, "%f", &sliceThickness_);
-   delete [] strn;
+	   sscanf(strn, "%f", &sliceThickness_);
+   }
+   
+   if (strn != NULL) delete [] strn;
    return true;
 }
 
@@ -1124,11 +1124,12 @@ bool DICOMImage::GetFOV()
 		// Make sure we have read the values for rows and columns (which should
 		// be positive
 
-		if (rows_ < 0)
-			if (GetRows())
+		if ( rows_ < 0 )
+		{
+			if ( GetRows() )
 			{
-				if (columns_ < 0)
-					if (! GetColumns())
+				if ( columns_ < 0 )
+					if ( ! GetColumns() )
 					{
 						delete [] strn;
 						return false;
@@ -1139,6 +1140,7 @@ bool DICOMImage::GetFOV()
 				delete [] strn;
 				return false;
 			}
+		}
 		
 		char *tok = strtok(strn, "\\");
 		yFOV_ = atof(tok) * float(rows_);
@@ -1445,8 +1447,6 @@ bool DICOMImage::GetPosNorm()
 
 bool DICOMImage::GetPosNormSiemens(char *storage)
 {
-	int found = 0;
-	  
 	// Find the info of the form "sSliceArray.asSlice[NN].sNormal.dSag/dCor/dTra"
 	// and "sSliceArray.asSlice[NN].sPosition.dSag/dCor/dTra" for each slice (if
 	// this a Mosaic, there will be more than one slice)
